diff --git a/components/lib/splitbutton/SplitButton.vue b/components/lib/splitbutton/SplitButton.vue
index 662094d66..0b4cd3f1a 100755
--- a/components/lib/splitbutton/SplitButton.vue
+++ b/components/lib/splitbutton/SplitButton.vue
@@ -2,9 +2,9 @@
-
+
-
+
@@ -21,9 +21,9 @@
@keydown="onDropdownKeydown"
v-bind="menuButtonProps"
>
-
+
-
+
diff --git a/components/lib/toolbar/Toolbar.vue b/components/lib/toolbar/Toolbar.vue
index 8328166a8..3f0b5377c 100755
--- a/components/lib/toolbar/Toolbar.vue
+++ b/components/lib/toolbar/Toolbar.vue
@@ -1,12 +1,12 @@
diff --git a/components/lib/toolbar/Toolbar.d.ts b/components/lib/toolbar/Toolbar.d.ts
index 60b4b2ab9..3b18445b6 100755
--- a/components/lib/toolbar/Toolbar.d.ts
+++ b/components/lib/toolbar/Toolbar.d.ts
@@ -29,17 +29,17 @@ export interface ToolbarPassThroughOptions {
*/
root?: ToolbarPassThroughOptionType;
/**
* Uses to pass attributes to the groupleft's DOM element.
*/
- groupleft?: ToolbarPassThroughOptionType;
+ groupStart?: ToolbarPassThroughOptionType;
/**
* Uses to pass attributes to the groupcenter's DOM element.
*/
- groupcenter?: ToolbarPassThroughOptionType;
+ groupCenter?: ToolbarPassThroughOptionType;
/**
* Uses to pass attributes to the groupright's DOM element.
*/
- groupright?: ToolbarPassThroughOptionType;
+ groupEnd?: ToolbarPassThroughOptionType;
}
/**
@@ -29,17 +29,17 @@ export interface ToolbarPassThroughOptions {
root?: ToolbarPassThroughOptionType;
/**
- * Uses to pass attributes to the groupleft's DOM element.
+ * Uses to pass attributes to the groupstart's DOM element.
*/